slepc-3.18.0 2022-10-01
Report Typos and Errors

# DSNEPSetSamplingSize

Sets the number of sampling columns to be used in the contour integral method.

### Synopsis

    #include "slepcds.h"
    #include "slepcrg.h"
    PetscErrorCode DSNEPSetSamplingSize(DS ds,PetscInt p)

Logically Collective on ds

### Input Parameters

| ds | - the direct solver context
| p | - the number of columns for the sampling matrix

### Options Database Key

| -ds_nep_sampling_size <p> | - sets the number of sampling columns

### Notes

This parameter is relevant only in the contour integral method.

### See Also

DSNEPGetSamplingSize()

### Level

advanced

### Location

src/sys/classes/ds/impls/nep/dsnep.c
Index of all DS routines
Table of Contents for all manual pages
Index of all manual pages